@@ -1,13 +1,13 @@
 """directories is used to generate the necessary directory structures."""
 from logging import INFO, Logger
-from os import PathLike
 from pathlib import Path
-from typing import Iterable, MutableSequence, Set, Union
+from typing import TYPE_CHECKING, Iterable, MutableSequence, Set
 
 from ansible_generator.log import setup_logger
 from ansible_generator.utilities import join_cwd_and_directory_path
 
-StrPath = Union[str, PathLike[str]]
+if TYPE_CHECKING:
+    from _typeshed import StrPath
 
 
 def create_directory_layout(
@@ -72,7 +72,7 @@ def create_directory_layout(
     return True
 
 
-def create_directory(logger: Logger, dir_path: StrPath) -> bool:
+def create_directory(logger: Logger, dir_path: "StrPath") -> bool:
     """Recursively creates a directory path if does not exist.
 
     Args:
