@@ -1,16 +1,16 @@
 """utilities are functions that need to be used by multiple files."""
-from os import PathLike
 from pathlib import Path
-from typing import Union
+from typing import TYPE_CHECKING
 
 from ansible_generator.log import setup_logger
 
+if TYPE_CHECKING:
+    from _typeshed import StrPath
+
 logger = setup_logger(name=__name__)
 
-StrPath = Union[str, PathLike[str]]
 
-
-def join_cwd_and_directory_path(dir_path: StrPath) -> Path:
+def join_cwd_and_directory_path(dir_path: "StrPath") -> Path:
     """Join the current working directory with the provided path.
 
     Args:
